@@ -81,7 +81,7 @@ int string_to_type(const char *);
 extern char _STR2[250], _STR[150];
 extern fontinfo *fonts;
 extern short fontcount;
-extern Clientdata areastruct;
+extern XCWindowData *areawin;
 extern Globaldata xobjs;
 extern short beeper; 
 extern Widget menuwidgets[];
@@ -161,7 +161,7 @@ static PyObject *pypopupprompt(PyObject *self, PyObject *args,
 
 
    getgeneric(savebutton, NULL, NULL, (void *)pfunction);
-   popupprompt(areastruct.area, (char *)prompt, displaystr,
+   popupprompt(areawinarea, (char *)prompt, displaystr,
 		pypromptvalue, savebutton, dofile);
 
    return PyInt_FromLong(0L);
@@ -681,7 +681,7 @@ static PyObject *xc_getpage(PyObject *self, PyObject *args)
 {
    Pagedata *thispage;
    PyObject *rdict, *dlist;
-   int pageno = areastruct.page + 1, i;
+   int pageno = areawinpage + 1, i;
 
    if (!PyArg_ParseTuple(args, "|d:getpage", &pageno))
       return NULL;
@@ -893,7 +893,7 @@ static PyObject *xc_netlist()
 {
    PyObject *rdict = NULL;
 
-   if (updatenets(areastruct.topinstance) <= 0) {
+   if (updatenets(areawintopinstance) <= 0) {
       PyErr_SetString(PyExc_TypeError, "Error:  Check circuit for infinite recursion.");
       return NULL;
    }
@@ -914,10 +914,10 @@ static PyObject *xc_load(PyObject *self, PyObject *args)
    int pageno = 0, savepage;
 
    if (!PyArg_ParseTuple(args, "s|i:load", &filename, &pageno))
-      return PyInt_FromLong((long)areastruct.page);
+      return PyInt_FromLong((long)areawinpage);
 
-   if (--pageno < 0) pageno = areastruct.page;
-   savepage = areastruct.page;
+   if (--pageno < 0) pageno = areawinpage;
+   savepage = areawinpage;
 
    strcpy(_STR2, filename);
    if (savepage != pageno) newpage(pageno);
@@ -936,7 +936,7 @@ static PyObject *xc_page(PyObject *self, PyObject *args)
    int pageno;
 
    if (!PyArg_ParseTuple(args, "i:page", &pageno))
-      return PyInt_FromLong((long)areastruct.page);
+      return PyInt_FromLong((long)areawinpage);
 
    newpage(pageno - 1);
    return PyInt_FromLong((long)pageno);
@@ -958,18 +958,18 @@ static PyObject *xc_zoom(PyObject *self, PyObject *args)
       return NULL;
    }
    
-   save = areastruct.zoomfactor;
+   save = areawinzoomfactor;
 
    if (factor < 1.0) {
-      areastruct.zoomfactor = 1.0 / factor;
+      areawinzoomfactor = 1.0 / factor;
       zoomout(NULL, NULL, NULL);
    }
    else {
-      areastruct.zoomfactor = factor;
+      areawinzoomfactor = factor;
       zoomin(NULL, NULL, NULL);
    }
 
-   areastruct.zoomfactor = save;
+   areawinzoomfactor = save;
    return PyFloat_FromDouble((double)topobject->viewscale);
 }
 
@@ -1007,8 +1007,8 @@ static PyObject *xc_pan(PyObject *self, PyObject *args)
    panbutton((u_int)5, &bevent);
 
    cornerpos = PyTuple_New(2);
-   PyTuple_SetItem(cornerpos, 0, PyInt_FromLong((long)areastruct.pcorner->x));
-   PyTuple_SetItem(cornerpos, 1, PyInt_FromLong((long)areastruct.pcorner->y));
+   PyTuple_SetItem(cornerpos, 0, PyInt_FromLong((long)areawinpcorner->x));
+   PyTuple_SetItem(cornerpos, 1, PyInt_FromLong((long)areawinpcorner->y));
 
    return cornerpos;
 }
@@ -1022,8 +1022,8 @@ static PyObject *xc_getwindow()
    PyObject *windowsize;
 
    windowsize = PyTuple_New(2);
-   PyTuple_SetItem(windowsize, 0, PyInt_FromLong((long)areastruct.width));
-   PyTuple_SetItem(windowsize, 1, PyInt_FromLong((long)areastruct.height));
+   PyTuple_SetItem(windowsize, 0, PyInt_FromLong((long)areawinwidth));
+   PyTuple_SetItem(windowsize, 1, PyInt_FromLong((long)areawinheight));
 
    return windowsize;
 }
@@ -1413,7 +1413,7 @@ static PyObject *xc_setattr(PyObject *self, PyObject *args)
 	 break;
    }
 
-   calcbbox(areastruct.topinstance);
+   calcbbox(areawintopinstance);
    return PyInt_FromLong((long)(*gelem));
 }
 /*--------------------------------------------------------------*/
@@ -1426,7 +1426,7 @@ static PyObject *xc_set(PyObject *self, PyObject *args)
    const char *sarg1, *sarg2;
    int i;
    Boolean a = True; 
-   short cpage = areastruct.page;
+   short cpage = areawinpage;
 
    if (!PyArg_ParseTuple(args, "ss:set", &sarg1, &sarg2))
       return NULL;
@@ -1447,26 +1447,26 @@ static PyObject *xc_set(PyObject *self, PyObject *args)
 
       for (i = 0; i < fontcount; i++) {
 	 if (!strcmp(fonts[i].psname, sarg2)) {
-            areastruct.psfont = i;
+            areawinpsfont = i;
             setdefaultfontmarks();
 	    break;
 	 }
       }
    }
    else if (!strcmp(sarg1, "fontscale")) {
-      sscanf(sarg2, "%f", &areastruct.textscale);
+      sscanf(sarg2, "%f", &areawintextscale);
    }
    else if (!strcmp(sarg1, "axis") || !strcmp(sarg1, "axes")) {
-      areastruct.axeson = a;
-      toggle(GridAxesButton, &areastruct.axeson, NULL);
+      areawinaxeson = a;
+      toggle(GridAxesButton, &areawinaxeson, NULL);
    }
    else if (!strcmp(sarg1, "grid")) {
-      areastruct.gridon = a;
-      toggle(GridGridButton, &areastruct.gridon, NULL);
+      areawingridon = a;
+      toggle(GridGridButton, &areawingridon, NULL);
    }  
    else if (!strcmp(sarg1, "snap") || !strcmp(sarg1, "snap-to")) {
-      areastruct.snapto = a;
-      toggle(SnaptoSnaptoButton, &areastruct.snapto, NULL);
+      areawinsnapto = a;
+      toggle(SnaptoSnaptoButton, &areawinsnapto, NULL);
    }
    else if (!strcmp(sarg1, "gridspace")) {
       sscanf(sarg2, "%f", &xobjs.pagelist[cpage]->gridspace);
@@ -1488,12 +1488,12 @@ static PyObject *xc_set(PyObject *self, PyObject *args)
       else if (!strcmp(sarg2, "normal")) boxedit(NULL, NORMAL, NULL);
    }
    else if (!strcmp(sarg1, "linewidth")) {
-      sscanf(sarg2, "%f", &areastruct.linewidth);
+      sscanf(sarg2, "%f", &areawinlinewidth);
    }
    else if (!strcmp(sarg1, "colorscheme")) {
       if (!strcmp(sarg2, "inverse"))
-         areastruct.invert = False;
-      inversecolor(NULL, &areastruct.invert, NULL);
+         areawininvert = False;
+      inversecolor(NULL, &areawininvert, NULL);
    }
    else if (!strcmp(sarg1, "coordstyle")) {
       if (!strcmp(sarg2, "cm") || !strcmp(sarg2, "centimeters")) {
@@ -1511,12 +1511,12 @@ static PyObject *xc_set(PyObject *self, PyObject *args)
    }
 
    else if (!strcmp(sarg1, "xschema") || !strcmp(sarg1, "schema")) {
-      areastruct.schemon = a;
+      areawinschemon = a;
       doxschema(OptionsEnableXSchemaButton, 1, NULL);
    }
 #ifdef HAVE_XPM
    else if (!strcmp(sarg1, "toolbar")) {
-      areastruct.toolbar_on = a;
+      areawintoolbar_on = a;
       dotoolbar(OptionsDisableToolbarButton, NULL, NULL);
     }
 #endif
@@ -1721,7 +1721,7 @@ static PyObject *xc_refresh(PyObject *self, PyObject *args)
       
    refresh(NULL, NULL, NULL);
 
-   while(XCheckWindowEvent(dpy, areastruct.areawin, ~NoEventMask, &event))
+   while(XCheckWindowEvent(dpy, areawinareawin, ~NoEventMask, &event))
          XtDispatchEvent(&event);
 
    return PyInt_FromLong(0L);
@@ -2067,15 +2067,15 @@ void loadrcfile()
 
    if (!(flags & FONTOVERRIDE)) {
       loadfontfile("Helvetica");
-      if (areastruct.psfont == -1)
+      if (areawinpsfont == -1)
          for (i = 0; i < fontcount; i++)
 	    if (!strcmp(fonts[i].psname, "Helvetica")) {
-	       areastruct.psfont = i;
+	       areawinpsfont = i;
 	       break;
 	    }
    }
 
-   if (areastruct.psfont == -1) areastruct.psfont = 0;
+   if (areawinpsfont == -1) areawinpsfont = 0;
 
    setdefaultfontmarks();
       
