@@ -51,7 +51,7 @@ extern int xctcl_push();
 extern int xctcl_pop();
 extern int xctcl_rotate();
 extern int xctcl_flip();
-extern int xctcl_set();
+extern int xctcl_config();
 extern int xctcl_page();
 extern int xctcl_spice();
 extern int xctcl_zoom();
@@ -108,7 +108,7 @@ static cmdstruct xc_commands[] =
    {"pop", (void *)xctcl_pop},
    {"rotate", (void *)xctcl_rotate},
    {"flip", (void *)xctcl_flip},
-   {"config", (void *)xctcl_set},
+   {"config", (void *)xctcl_config},
    {"page", (void *)xctcl_page},
    {"zoom", (void *)xctcl_zoom},
    {"pan", (void *)xctcl_pan},
